@@ -1,5 +1,5 @@
 from datetime import datetime, timezone, timedelta
-from typing import List, Optional
+from typing import List, Optional, Union
 from .utils import convert_datetime_to_milli_epoch
 
 
@@ -222,8 +222,23 @@ class DataBricksRunningTime:
         start_timestamp = None
         current_num_workers = None
         for event in databricks_event[::-1]:
+            if cluster_status == "TERMINATED" and event.type == "CREATING":
+                cluster_status = "CREATING"
+                start_timestamp = event.timestamp
+                _cluster_num_candidate: Union[dict, int] = event.details.get("autoscale", 1)
+                if type(_cluster_num_candidate) is dict:
+                    current_num_workers = _cluster_num_candidate.get("min_workers")
 
-            if cluster_status == "TERMINATED" and event.type == "RUNNING":
+            elif cluster_status == "CREATING" and event.type == "RUNNING":
+                cluster_status = "RUNNING"
+                end_timestamp = event.timestamp
+                current_num_workers = event.details['current_num_workers']
+                cluster_id = event.cluster_id
+                running_time = DataBricksRunningTime(cluster_id, start_timestamp, end_timestamp, current_num_workers)
+                status_list.append(running_time)
+                start_timestamp = end_timestamp + 1
+
+            elif cluster_status == "TERMINATED" and event.type == "RUNNING":
                 cluster_status = "RUNNING"
                 start_timestamp = event.timestamp
                 current_num_workers = event.details['current_num_workers']
@@ -245,6 +260,16 @@ class DataBricksRunningTime:
                 start_timestamp = None
         return status_list
 
+    def dumps(self) -> dict:
+        return {
+            "cluster_id": self.cluster_id,
+            "current_num_workers": self.current_num_workers,
+            "start_timestamp": self.start_timestamp,
+            "end_timestamp": self.end_timestamp,
+            "start": f"{self.start_ymd}T{self.start_hms}",
+            "end": f"{self.end_ymd}T{self.end_hms}"
+        }
+
     def __str__(self):
         s_list = [
             f"* {self.duration_sec / 60: 0.1f}[min]",
@@ -355,3 +380,14 @@ class DatabricksSettingHistory:
             return latest_cluster
         else:
             raise ValueError("Out of range.")
+
+
+class DatabricksView:
+    def __init__(self, payload: dict):
+        self.content = payload['content']
+        self.name = payload['name']
+        self.type = payload['type']
+
+    @classmethod
+    def get_from_runs_export(cls, payload):
+        return [DatabricksView(p) for p in payload]
